@@ -1,3 +1,4 @@
+/* -*- mode: c; c-file-style: "bsd"; -*- */
 /*
     Internal shared data and functions.
 
@@ -20,7 +21,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: internal.h,v 1.52 2003/08/27 16:26:23 joq Exp $
+    $Id: internal.h,v 1.59 2003/12/16 06:08:38 joq Exp $
 */
 
 #ifndef __jack_internal_h__
@@ -46,7 +47,7 @@
 
 #ifdef DEBUG_ENABLED
 #define DEBUG(format,args...) \
-	printf ("jack:%5d:%" PRIu64 " %s:%s:%d: " format "\n", getpid(), jack_get_microseconds(), __FILE__, __FUNCTION__, __LINE__ , ## args)
+	fprintf (stderr, "jack:%5d:%" PRIu64 " %s:%s:%d: " format "\n", getpid(), jack_get_microseconds(), __FILE__, __FUNCTION__, __LINE__ , ## args)
 #else
 #if defined(__APPLE__) && defined(__POWERPC__) 
     #define DEBUG(format...)
@@ -60,7 +61,7 @@
 #endif
 
 #ifndef	TRUE
-#define	TRUE	(!FALSE)
+#define	TRUE	(1)
 #endif
 
 typedef struct _jack_engine  jack_engine_t;
@@ -68,11 +69,6 @@ typedef struct _jack_request jack_request_t;
 
 typedef void * dlhandle;
 
-typedef struct {
-    const char *shm_name;
-    size_t offset;			/* JOQ: 32/64 problem? */
-} jack_port_buffer_info_t;
-
 typedef enum {
     TransportCommandNone = 0,
     TransportCommandStart = 1,
@@ -86,13 +82,6 @@ typedef struct {
     volatile jack_time_t guard2;
 } jack_frame_timer_t;
 
-/* the relatively low value of this constant
- * reflects the fact that JACK currently only
- * knows about *1* port type.  (March 2003)
- */              
-
-#define JACK_MAX_PORT_TYPES 4
-
 /* JACK engine shared memory data structure. */
 typedef struct {
 
@@ -107,15 +96,15 @@ typedef struct {
     int8_t		  new_pos;	/* new position this cycle */
     int8_t		  pending_pos;	/* new position request pending */
     jack_nframes_t	  pending_frame; /* pending frame number */
-    uint32_t		  sync_clients;	/* number of is_slowsync clients */
-    uint32_t		  sync_remain;	/* number of them with sync_poll */
+    int32_t		  sync_clients;	/* number of active_slowsync clients */
+    int32_t		  sync_remain;	/* number of them with sync_poll */
     jack_time_t           sync_timeout;
     jack_time_t           sync_time_left;
     jack_frame_timer_t    frame_timer;
     int32_t		  internal;
     jack_nframes_t        frames_at_cycle_start;
     pid_t                 engine_pid;
-    uint32_t		  buffer_size;
+    jack_nframes_t	  buffer_size;
     int8_t		  real_time;
     int32_t		  client_priority;
     int32_t		  has_capabilities;
@@ -131,13 +120,15 @@ typedef struct {
 typedef enum  {
   BufferSizeChange,
   SampleRateChange,
-  NewPortType,
+  AttachPortSegment,
   PortConnected,
   PortDisconnected,
   GraphReordered,
   PortRegistered,
   PortUnregistered,
   XRun,
+  StartFreewheel,
+  StopFreewheel
 } EventType;
 
 typedef struct {
@@ -146,16 +137,12 @@ typedef struct {
 	uint32_t n;
 	jack_port_id_t port_id;
 	jack_port_id_t self_id;
-	shm_name_t shm_name;
     } x;
     union {
 	uint32_t n;
+	jack_port_type_id_t ptid;
 	jack_port_id_t other_id;
-	void* addr;			/* JOQ: 32/64 problem? */
     } y;
-    union { 
-	size_t size;			/* JOQ: 32/64 problem? */
-    } z;
 } jack_event_t;
 
 typedef enum {
@@ -179,22 +166,27 @@ typedef volatile struct {
     volatile jack_client_state_t state;   /* w: engine and client r: engine */
     volatile int8_t     name[JACK_CLIENT_NAME_SIZE+1];
     volatile ClientType type;             /* w: engine r: engine and client */
-    volatile int8_t     active : 1;       /* w: engine r: engine and client */
-    volatile int8_t     dead : 1;         /* r/w: engine */
-    volatile int8_t	timed_out : 1;    /* r/w: engine */
-    volatile int8_t     is_timebase : 1;  /* w: engine, r: engine and client */
-    volatile int8_t     is_slowsync : 1;  /* w: engine, r: engine and client */
-    volatile int8_t     sync_poll : 1;    /* w: engine and client, r: engine */
-    volatile int8_t     sync_new : 1;     /* w: engine and client, r: engine */
+    volatile int8_t     active;           /* w: engine r: engine and client */
+    volatile int8_t     dead;             /* r/w: engine */
+    volatile int8_t	timed_out;        /* r/w: engine */
+    volatile int8_t     is_timebase;	  /* w: engine, r: engine and client */
+    volatile int8_t     timebase_new;	  /* w: engine and client, r: engine */
+    volatile int8_t     is_slowsync;	  /* w: engine, r: engine and client */
+    volatile int8_t     active_slowsync;  /* w: engine, r: engine and client */
+    volatile int8_t     sync_poll;        /* w: engine and client, r: engine */
+    volatile int8_t     sync_new;         /* w: engine and client, r: engine */
     volatile pid_t      pid;              /* w: client r: engine; client pid */
+    volatile pid_t      pgrp;             /* w: client r: engine; client pgrp */
     volatile uint64_t	signalled_at;
     volatile uint64_t	awake_at;
     volatile uint64_t	finished_at;
 
     /* JOQ: all these pointers are trouble for 32/64 compatibility,
-     * they should move to non-shared memory. */
+     * they should move to non-shared memory. 
+     */
 
-    /* callbacks */
+    /* callbacks 
+     */
     JackProcessCallback process;
     void *process_arg;
     JackBufferSizeCallback bufsize;
@@ -211,7 +203,9 @@ typedef volatile struct {
     void *sync_arg;
     JackTimebaseCallback timebase_cb;
     void *timebase_arg;
-
+    JackFreewheelCallback freewheel_cb;
+    void *freewheel_arg;
+	
     /* external clients: set by libjack
      * internal clients: set by engine */
     int (*deliver_request)(void*, jack_request_t*);
@@ -239,28 +233,21 @@ typedef struct {
 
     uint32_t	protocol_v;
 
-    shm_name_t	client_shm_name;
-    shm_name_t	control_shm_name;
+    jack_shm_info_t client_shm;
+    jack_shm_info_t engine_shm;
 
-    int8_t	fifo_prefix[PATH_MAX+1];
+    char	fifo_prefix[PATH_MAX+1];
 
     int32_t	realtime;
     int32_t	realtime_priority;
 
     /* these two are valid only if the connect request
-       was for type == ClientDriver.
+       was for type == ClientDriver. 
     */
 
-    jack_client_control_t *client_control;
-    jack_control_t        *engine_control;
-    size_t                 control_size; /* JOQ: 32/64 problem? */
+    jack_client_control_t *client_control; /* JOQ: 64/32 problem */
+    jack_control_t        *engine_control; /* JOQ: 64/32 problem */
 
-    /* when we write this response, we deliver n_port_types
-       of jack_port_type_info_t after it.
-    */
-
-    uint32_t	n_port_types;
-    
 #if defined(__APPLE__) && defined(__POWERPC__) 
     /* specific resources for server/client real-time thread communication */
     int32_t	portnum;
@@ -292,6 +279,9 @@ typedef enum {
 	SetSyncClient = 13,
 	ResetSyncClient = 14,
 	SetSyncTimeout = 15,
+	SetBufferSize = 16,
+	FreeWheel = 17,
+	StopFreeWheel = 18,
 } RequestType;
 
 struct _jack_request {
@@ -301,9 +291,9 @@ struct _jack_request {
 	struct {
 	    char name[JACK_PORT_NAME_SIZE+1];
 	    char type[JACK_PORT_TYPE_SIZE+1];
-	    uint32_t flags;
-	    uint32_t buffer_size;
-	    jack_port_id_t port_id;
+	    uint32_t         flags;
+	    jack_shmsize_t   buffer_size;
+	    jack_port_id_t   port_id;
 	    jack_client_id_t client_id;
 	} port_info;
 	struct {
@@ -326,7 +316,9 @@ struct _jack_request {
 };
 
 /* per-client structure allocated in the server's address space
- * JOQ: then why isn't this in engine.h? */
+ * its here because its not part of the engine structure.
+ */
+
 typedef struct _jack_client_internal {
 
     jack_client_control_t *control;
@@ -337,7 +329,7 @@ typedef struct _jack_client_internal {
     int        subgraph_wait_fd;
     JSList    *ports;    /* protected by engine->client_lock */
     JSList    *fed_by;   /* protected by engine->client_lock */
-    shm_name_t shm_name;
+    jack_shm_info_t control_shm;
     unsigned long execution_order;
     struct  _jack_client_internal *next_client; /* not a linked list! */
     dlhandle handle;
@@ -359,21 +351,22 @@ extern void jack_cleanup_files ();
 
 extern int  jack_client_handle_port_connection (jack_client_t *client,
 						jack_event_t *event);
-extern void jack_client_handle_new_port_type (jack_client_t *client,
-					      shm_name_t, size_t, void* addr);
-
 extern jack_client_t *jack_driver_client_new (jack_engine_t *,
 					      const char *client_name);
-jack_client_t *jack_client_alloc_internal (jack_client_control_t*,
-					   jack_control_t*);
+extern jack_client_t *jack_client_alloc_internal (jack_client_control_t*,
+						  jack_engine_t*);
 
 /* internal clients call this. it's defined in jack/engine.c */
 void handle_internal_client_request (jack_control_t*, jack_request_t*);
 
 extern char *jack_server_dir;
 
+extern void *jack_zero_filled_buffer;
+
 extern void jack_error (const char *fmt, ...);
 
+extern jack_port_functions_t jack_builtin_audio_functions;
+
 extern jack_port_type_info_t jack_builtin_port_types[];
 
 extern void jack_client_invalidate_port_buffers (jack_client_t *client);
@@ -384,5 +377,10 @@ extern void jack_call_sync_client (jack_client_t *client);
 
 extern void jack_call_timebase_master (jack_client_t *client);
 
+extern int jack_acquire_real_time_scheduling (pthread_t, int priority);
+extern int jack_drop_real_time_scheduling (pthread_t);
+
+void silent_jack_error_callback (const char *desc);
+
 #endif /* __jack_internal_h__ */
 
