@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software 
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: jack.h,v 1.46 2003/08/27 16:26:23 joq Exp $
+    $Id: jack.h,v 1.55 2004/01/09 18:43:47 joq Exp $
 */
 
 #ifndef __jack_h__
@@ -35,7 +35,13 @@ extern "C" {
  */
 
 /**
- * Attemps to become an external client of the Jack server.
+ * Attempts to become an external client of the Jack server.
+ *
+ * @return opaque client handle if successful, otherwise NULL.
+ *
+ * Note: failure generally means that the JACK server is not running.
+ * If there was some other problem, it will be reported via the
+ * @ref jack_error_callback mechanism.
  */
 jack_client_t *jack_client_new (const char *client_name);
 
@@ -87,44 +93,104 @@ int jack_is_realtime (jack_client_t *client);
  *
  * NOTE: clients do not need to call this.  It exists only
  * to help more complex clients understand what is going
- * on.  If called, it should be called before jack_client_activate().
+ * on.  It should be called before jack_client_activate().
  */
 void jack_on_shutdown (jack_client_t *client, void (*function)(void *arg), void *arg);
 
 /**
- * Tell the Jack server to call 'process_callback' whenever there is work
- * be done, passing 'arg' as the second argument.
+ * Tell the Jack server to call @a process_callback whenever there is
+ * work be done, passing @a arg as the second argument.
  *
  * The code in the supplied function must be suitable for real-time
- * execution.  That means that it cannot call functions that might block for
- * a long time. This includes malloc, free, printf, pthread_mutex_lock,
- * sleep, wait, poll, select, pthread_join, pthread_cond_wait, etc, etc.
- * See
+ * execution.  That means that it cannot call functions that might
+ * block for a long time. This includes malloc, free, printf,
+ * pthread_mutex_lock, sleep, wait, poll, select, pthread_join,
+ * pthread_cond_wait, etc, etc. See
  * http://jackit.sourceforge.net/docs/design/design.html#SECTION00411000000000000000
  * for more information.
- * 
  *
  * @return 0 on success, otherwise a non-zero error code, causing JACK
  * to remove that client from the process() graph.
  */
-int jack_set_process_callback (jack_client_t *, JackProcessCallback process_callback, void *arg);
+int jack_set_process_callback (jack_client_t *client,
+			       JackProcessCallback process_callback,
+			       void *arg);
 
 /**
- * Tell the Jack server to call 'bufsize_callback' whenever the size of the
- * the buffer that will be passed to the process callback changes, 
- * passing 'arg' as the second argument.
+ * Tell the Jack server to call @a freewheel_callback
+ * whenever we enter or leave "freewheel" mode, passing @a
+ * arg as the second argument. The first argument to the
+ * callback will be non-zero if JACK is entering freewheel
+ * mode, and zero otherwise.
+ *
+ * @return 0 on success, otherwise a non-zero error code.
+ */
+int jack_set_freewheel_callback (jack_client_t *client,
+				 JackFreewheelCallback freewheel_callback,
+				 void *arg);
+
+/**
+ * Start/Stop JACK's "freewheel" mode.
+ *
+ * When in "freewheel" mode, JACK no longer waits for
+ * any external event to begin the start of the next process
+ * cycle. 
+ *
+ * As a result, freewheel mode causes "faster than realtime"
+ * execution of a JACK graph. If possessed, real-time
+ * scheduling is dropped when entering freewheel mode, and
+ * if appropriate it is reacquired when stopping.
+ * 
+ * @param client pointer to JACK client structure
+ * @param onoff  if non-zero, freewheel mode starts. Otherwise
+ *                  freewheel mode ends.
+ *
+ * @return 0 on success, otherwise a non-zero error code.
+ */
+int jack_set_freewheel(jack_client_t* client, int onoff);
+
+/**
+ * Change the buffer size passed to the @a process_callback.
+ *
+ * This operation stops the JACK engine process cycle, then calls all
+ * registered @a bufsize_callback functions before restarting the
+ * process cycle.  This will cause a gap in the audio flow, so it
+ * should only be done at appropriate stopping points.
+ *
+ * @see jack_set_buffer_size_callback()
+ *
+ * @param client pointer to JACK client structure.
+ * @param nframes new buffer size.  Must be a power of two.
  *
  * @return 0 on success, otherwise a non-zero error code
  */
-int jack_set_buffer_size_callback (jack_client_t *, JackBufferSizeCallback bufsize_callback, void *arg);
+int jack_set_buffer_size (jack_client_t *client, jack_nframes_t nframes);
 
 /**
- * Tell the Jack server to call 'srate_callback' whenever the sample rate of
- * the system changes.
+ * Tell JACK to call @a bufsize_callback whenever the size of the the
+ * buffer that will be passed to the @a process_callback is about to
+ * change.  Clients that depend on knowing the buffer size must supply
+ * a @a bufsize_callback before activating themselves.
+ *
+ * @param client pointer to JACK client structure.
+ * @param bufsize_callback function to call when the buffer size changes.
+ * @param arg argument for @a bufsize_callback.
  *
  * @return 0 on success, otherwise a non-zero error code
  */
-int jack_set_sample_rate_callback (jack_client_t *, JackSampleRateCallback srate_callback, void *arg);
+int jack_set_buffer_size_callback (jack_client_t *client,
+				   JackBufferSizeCallback bufsize_callback,
+				   void *arg);
+
+/**
+ * Tell the Jack server to call @a srate_callback whenever the system
+ * sample rate changes.
+ *
+ * @return 0 on success, otherwise a non-zero error code
+ */
+int jack_set_sample_rate_callback (jack_client_t *client,
+				   JackSampleRateCallback srate_callback,
+				   void *arg);
 
 /**
  * Tell the Jack server to call 'registration_callback' whenever a port is registered
@@ -185,16 +251,14 @@ int jack_deactivate (jack_client_t *client);
  * character.
  *
  * A port has a type, which may be any non-NULL and non-zero length
- * string, and is passed as the second argument. For types that are
- * not built into the jack API (currently just
- * JACK_DEFAULT_AUDIO_TYPE) the client MUST supply a non-zero size
- * for the buffer as for 'buffer_size' . For builtin types, 
- * 'buffer_size' is ignored.
+ * string, and is passed as the second argument.  Some port types are
+ * built into the JACK API (currently only JACK_DEFAULT_AUDIO_TYPE).
+ * For other types, the client must supply a non-zero @a buffer_size.
+ * For builtin types, @a buffer_size is ignored.
  *
- * The 'flags' argument is formed from a bitmask of JackPortFlags values.
+ * The @a flags argument is formed from a bitmask of JackPortFlags values.
  *
  * @return a valid jack_port_t* on success, NULL otherwise.
- * returns NULL.
  */
 jack_port_t *jack_port_register (jack_client_t *,
                                  const char *port_name,
@@ -385,26 +449,6 @@ void jack_port_set_latency (jack_port_t *, jack_nframes_t);
  */
 int jack_port_set_name (jack_port_t *port, const char *name);
 
-/**
- */
-
-double jack_port_get_peak (jack_port_t*, jack_nframes_t);
-
-/**
- */
-
-double jack_port_get_power (jack_port_t*, jack_nframes_t);
-
-/**
- */
-
-void jack_port_set_peak_function (jack_port_t *, double (*func)(jack_port_t*, jack_nframes_t));
-
-/**
- */
-
-void jack_port_set_power_function (jack_port_t *, double (*func)(jack_port_t*, jack_nframes_t));
-
 /**
  * If JackPortCanMonitor is set for a port, then these 2 functions will
  * turn on/off input monitoring for the port. If JackPortCanMonitor
@@ -447,7 +491,8 @@ int jack_port_monitoring_input (jack_port_t *port);
  * @pre The flags of the source port must include PortIsOutput.
  * @pre The flags of the destination port must include PortIsInput.
  *
- * @return 0 on success, otherwise a non-zero error code
+ * @return 0 on success, EEXIST if the connection is allready made, otherwise
+ * a non-zero error code
  */
 int jack_connect (jack_client_t *,
 		  const char *source_port,
@@ -497,11 +542,13 @@ int jack_port_disconnect (jack_client_t *, jack_port_t *);
 jack_nframes_t jack_get_sample_rate (jack_client_t *);
 
 /**
- * This returns the current maximum size that will
- * ever be passed to the "process" callback.  It should only
- * be used *before* the client has been activated.  After activation,
- * the client will be notified of buffer size changes if it
- * registers a buffer_size callback.
+ * This returns the current maximum size that will ever be passed to
+ * the @a process_callback.  It should only be used *before* the
+ * client has been activated.  This size may change, clients that
+ * depend on it must register a @a bufsize_callback so they will be
+ * notified if it does.
+ *
+ * @see jack_set_buffer_size_callback()
  */
 jack_nframes_t jack_get_buffer_size (jack_client_t *);
 
@@ -547,11 +594,6 @@ jack_port_t *jack_port_by_id (const jack_client_t *client, jack_port_id_t id);
  */
 int  jack_engine_takeover_timebase (jack_client_t *);
 
-/**
- * undocumented
- */
-void jack_update_time (jack_client_t *, jack_nframes_t);
-
 /**
  * This estimates the time that has passed since the JACK server
  * started calling the process callbacks of all its clients.
@@ -582,6 +624,9 @@ float jack_cpu_load (jack_client_t *client);
  * jack_client_new() if the server was started
  * with arguments telling it to use a non-standard
  * directory.
+ * 
+ * @deprecated This function is deprecated.  Don't use in new programs
+ * and remove it in old programs.
  */
 void jack_set_server_dir (const char *path);
 
@@ -591,10 +636,21 @@ void jack_set_server_dir (const char *path);
  */
 pthread_t jack_client_thread_id (jack_client_t *);
 
-extern void (*jack_error_callback)(const char *desc);
+/**
+ * Function called for displaying JACK error messages.
+ *
+ * Set via jack_set_error_function(), otherwise a JACK-provided
+ * default will print @a msg (plus a newline) to stderr.
+ *
+ * @param msg error message text (no newline at end).
+ */
+extern void (*jack_error_callback)(const char *msg);
 
 /**
- * Sets callback to be called to print error messages.
+ * Set the @ref jack_error_callback for error message display.
+ *
+ * The JACK library provides two built-in callbacks for this purpose:
+ * default_jack_error_callback() and silent_jack_error_callback().
  */
 void jack_set_error_function (void (*func)(const char *));
 
