@@ -6,19 +6,29 @@ struct _jack_client {
 
     jack_control_t        *engine;
     jack_client_control_t *control;
-    struct pollfd *pollfd;
-    int pollmax;
-    int graph_next_fd;
-    int request_fd;
-    JSList *port_segments;
+    jack_shm_info_t        engine_shm;
+    jack_shm_info_t        control_shm;
+
+    struct pollfd* pollfd;
+    int            pollmax;
+    int            graph_next_fd;
+    int            request_fd;
+
+    /* these two are copied from the engine when the 
+     * client is created.
+    */
+
+    jack_port_type_id_t n_port_types;
+    jack_shm_info_t*    port_segment;
+
     JSList *ports;
+
     pthread_t thread;
     char fifo_prefix[PATH_MAX+1];
     void (*on_shutdown)(void *arg);
     void *on_shutdown_arg;
     char thread_ok : 1;
     char first_active : 1;
-    char new_timebase : 1;
     pthread_t thread_id;
     
 #if defined(__APPLE__) && defined(__POWERPC__)
